@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 ##############################################################
 # smscon_service - remote control daemon for Nokia N900 phone#
-# $Id: smscon_service.py 78 2011-12-23 23:12:29Z yablacky $
+# $Id: smscon_service.py 87 2011-12-25 14:54:03Z yablacky $
 ##############################################################
 
 # standard modules
@@ -53,6 +53,7 @@ ConnectionIAP               = None
 ConnectionName              = None
 ConnectionBehaviour         = None
 
+IsTestModeActive            = False
 IsKeyboardSliderCheckActive = False
 IsBatteryStatusCheckActive  = False
 IsCheckHostActive           = False
@@ -1624,7 +1625,9 @@ def DoCommandLine():
     """
     Check arguments for smscon_daemon and perform corresponding actions.
     @return bool True if ok
-    """    
+    """
+    global IsTestModeActive;
+
     def TellError(Msg):
         LOGGER.error(Msg)
         return False
@@ -1640,6 +1643,7 @@ def DoCommandLine():
         if Mode == '-test':
             if len(args) == 0: return TellError('%s requires argument.' % Mode)
             Func = args.pop(0)
+            IsTestModeActive = True
     
             if Func == 'gps1' or Func == 'gps2': 
                 RememberNetworkSettings()
@@ -1713,9 +1717,10 @@ def DoCommandLine():
         elif Mode == '-comtest':
             if len(args) == 0: return TellError('%s requires argument.' % Mode)
             Command = args.pop(0)
+            IsTestModeActive = True
 
-            LOGGER.warning('Simulating received SMS message with "%s" command.' % Command)
-            ProcessCommand(Command, SenderPhoneNumber = smscnf.SENDERNUMBER,
+            LOGGER.warning('Simulating received SMS message from MASTERNUMBER with "%s" command.' % Command)
+            ProcessCommand(Command, SenderPhoneNumber = smscnf.MASTERNUMBER,
                            ExtraInfo = 'SIMULATION!', LogIfCmdUnknown = True)    
         else:
             LOGGER.warning('Option error (%s) - ignored' % Mode)
@@ -1726,7 +1731,7 @@ def DoCommandLine():
 
 #############################################
 
-def CheckBootLoader():
+def CheckBootLoader(WithNotification = True):
     """
     Check if smscon auto-loads at system boot.
     @return void.
@@ -1735,7 +1740,8 @@ def CheckBootLoader():
         LOGGER.info('%s auto-loads at boot. OK.' % smscon.NAME)
     else:
         LOGGER.warning(    "%s does not auto-load at boot." % smscon.NAME)
-        RevealThat('boot', "%s does not auto-load at boot." % smscon.NAME)        
+        if WithNotification:
+            RevealThat('boot', "%s does not auto-load at boot." % smscon.NAME)        
 
 def ExitDaemon(ExitReason = 'regularly'):
     """
@@ -1792,7 +1798,7 @@ def OnBatteryStatusChange(BarLevel, BarLevelMax):
     if Message != LastBatteryStatusMessage:
         LastBatteryStatusMessage = Message
         LOGGER.info(Message)
-        if (Charging != None and not Charging) or (ChargePercent != None and ChargePercent < ChargePercentMin): 
+        if (Charging == None or not Charging) and (ChargePercent != None and ChargePercent < ChargePercentMin): 
             RevealThat('battery warning', Message)
 
 #############################################
@@ -1980,7 +1986,6 @@ def main():
     
     LoadConfiguration() or ExitDaemon('on config load error')
     ValidateIMSI()
-    CheckBootLoader()
     
     # Connect to various signal triggers:
     try:            
@@ -2021,8 +2026,10 @@ def main():
     
         if not DoCommandLine():
             ExitDaemon('bad command line')
-    
+
         InstallSignalReceivers()
+
+        CheckBootLoader(WithNotification = not IsTestModeActive)
     
         gobject.MainLoop().run()
     
