@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 ##############################################################
 # smscon - remote control library for Nokia N900 phone       #
-# $Id: smsconlib.py 86 2011-12-25 14:52:38Z yablacky $
+# $Id: smsconlib.py 90 2011-12-26 10:35:03Z yablacky $
 ##############################################################
 
 # standard modules
@@ -21,7 +21,7 @@ def getSysBuildNameAndVersion(defaultName, defaultVersion = '999.1', headerInfo
     Analyze information from version control system to find out name and version of a branch.
     @param string defaultName Name to return if version information not recognized.
     @param string defaultVersion Version to return if version information not recognized.
-    @param string headerInfo Value from expanded $Header: https://vcs.maemo.org/svn/smscon/branches/smscon_0.9.7/src/opt/smscon/smsconlib.py 86 2011-12-25 14:52:38Z yablacky $ keyword to be analyzed.
+    @param string headerInfo Value from expanded $Header: https://vcs.maemo.org/svn/smscon/branches/smscon_0.9.8/src/opt/smscon/smsconlib.py 90 2011-12-26 10:35:03Z yablacky $ keyword to be analyzed.
     @param int dirLevel Number of extra dirs to walk up to find the one that contains version information (0 = parent dir).
     @return list (name, version) The name and version information.
     """
@@ -34,7 +34,7 @@ NAME = 'smscon'
 VERSION = '999.1'   # for trunk and private builds etc.
 
 NAME, VERSION = getSysBuildNameAndVersion(NAME, VERSION,
-    headerInfo  = '$Header: https://vcs.maemo.org/svn/smscon/branches/smscon_0.9.7/src/opt/smscon/smsconlib.py 86 2011-12-25 14:52:38Z yablacky $',
+    headerInfo  = '$Header: https://vcs.maemo.org/svn/smscon/branches/smscon_0.9.8/src/opt/smscon/smsconlib.py 90 2011-12-26 10:35:03Z yablacky $',
     dirLevels   = 3 )
     
 XDEBUG   = False        # cross debug (use only if not running on phone)
@@ -134,7 +134,7 @@ def pidof(ProcessName):
     if PIDs != '':
         return PIDs
     PIDs = []
-    for psLine in os.popen('ps -ef|grep -v grep|grep %s' % shellArg(' ' + ProcessName)).readlines():
+    for psLine in os.popen('ps -e -o pid,user,vsz,stat,cmd|grep -v grep|grep %s' % shellArg(' ' + ProcessName)).readlines():
         PIDs.append(psLine.split()[0])
     return ' '.join(PIDs)
 
@@ -1005,10 +1005,14 @@ class smscon_script:
 # Script output (stdout and stderr) can be retrieved by COM_CUSTOMLOG command.
 
 # Here are some example commands you might consider:
-echo ps:
+echo Process list on $(date):
 ps
 echo netstat:
-netstat -tean    
+netstat -tean
+
+# Another idea might be to add commands to clean or remove all
+# personal data files from phone: multimedia files, picutes, music,
+# mail, contact data, etc.. But this is up to you. 
 """
         Filename = self.Filename
         Thing = 'script file "%s"' % self.Filename
